monitor

package
v0.0.0-...-483b314 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 27, 2023 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the monitor type in the database.
	Label = "monitor"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldDescription holds the string denoting the description field in the database.
	FieldDescription = "description"
	// FieldCurrentDownReason holds the string denoting the current_down_reason field in the database.
	FieldCurrentDownReason = "current_down_reason"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldLastCheckedAt holds the string denoting the last_checked_at field in the database.
	FieldLastCheckedAt = "last_checked_at"
	// FieldStatusLastChangedAt holds the string denoting the status_last_changed_at field in the database.
	FieldStatusLastChangedAt = "status_last_changed_at"
	// FieldMonitorType holds the string denoting the monitor_type field in the database.
	FieldMonitorType = "monitor_type"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldConfig holds the string denoting the config field in the database.
	FieldConfig = "config"
	// FieldIntervalSeconds holds the string denoting the interval_seconds field in the database.
	FieldIntervalSeconds = "interval_seconds"
	// FieldPaused holds the string denoting the paused field in the database.
	FieldPaused = "paused"
	// FieldFailureCount holds the string denoting the failure_count field in the database.
	FieldFailureCount = "failure_count"
	// FieldSuccessCount holds the string denoting the success_count field in the database.
	FieldSuccessCount = "success_count"
	// FieldSuccessThreshold holds the string denoting the success_threshold field in the database.
	FieldSuccessThreshold = "success_threshold"
	// FieldFailureThreshold holds the string denoting the failure_threshold field in the database.
	FieldFailureThreshold = "failure_threshold"
	// FieldTags holds the string denoting the tags field in the database.
	FieldTags = "tags"
	// FieldSilenced holds the string denoting the silenced field in the database.
	FieldSilenced = "silenced"
	// EdgeAlertChannels holds the string denoting the alert_channels edge name in mutations.
	EdgeAlertChannels = "alert_channels"
	// Table holds the table name of the monitor in the database.
	Table = "monitors"
	// AlertChannelsTable is the table that holds the alert_channels relation/edge. The primary key declared below.
	AlertChannelsTable = "alert_channel_monitors"
	// AlertChannelsInverseTable is the table name for the AlertChannel entity.
	// It exists in this package in order to avoid circular dependency with the "alertchannel" package.
	AlertChannelsInverseTable = "alert_channels"
)

Variables

var (
	// DefaultDescription holds the default value on creation for the "description" field.
	DefaultDescription string
	// DefaultCurrentDownReason holds the default value on creation for the "current_down_reason" field.
	DefaultCurrentDownReason string
	// DefaultStatusLastChangedAt holds the default value on creation for the "status_last_changed_at" field.
	DefaultStatusLastChangedAt func() time.Time
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultIntervalSeconds holds the default value on creation for the "interval_seconds" field.
	DefaultIntervalSeconds int
	// DefaultPaused holds the default value on creation for the "paused" field.
	DefaultPaused bool
	// DefaultFailureCount holds the default value on creation for the "failure_count" field.
	DefaultFailureCount int
	// DefaultSuccessCount holds the default value on creation for the "success_count" field.
	DefaultSuccessCount int
	// DefaultSuccessThreshold holds the default value on creation for the "success_threshold" field.
	DefaultSuccessThreshold int
	// DefaultFailureThreshold holds the default value on creation for the "failure_threshold" field.
	DefaultFailureThreshold int
	// DefaultSilenced holds the default value on creation for the "silenced" field.
	DefaultSilenced bool
	// IDValidator is a validator for the "id" field. It is called by the builders before save.
	IDValidator func(string) error
)
var (
	// AlertChannelsPrimaryKey and AlertChannelsColumn2 are the table columns denoting the
	// primary key for the alert_channels relation (M2M).
	AlertChannelsPrimaryKey = []string{"alert_channel_id", "monitor_id"}
)

Columns holds all SQL columns for monitor fields.

Functions

func And

func And(predicates ...predicate.Monitor) predicate.Monitor

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.Monitor

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Monitor

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Monitor

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Monitor

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Monitor

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Monitor

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Monitor

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Monitor

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Monitor

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CurrentDownReason

func CurrentDownReason(v string) predicate.Monitor

CurrentDownReason applies equality check predicate on the "current_down_reason" field. It's identical to CurrentDownReasonEQ.

func CurrentDownReasonContains

func CurrentDownReasonContains(v string) predicate.Monitor

CurrentDownReasonContains applies the Contains predicate on the "current_down_reason" field.

func CurrentDownReasonContainsFold

func CurrentDownReasonContainsFold(v string) predicate.Monitor

CurrentDownReasonContainsFold applies the ContainsFold predicate on the "current_down_reason" field.

func CurrentDownReasonEQ

func CurrentDownReasonEQ(v string) predicate.Monitor

CurrentDownReasonEQ applies the EQ predicate on the "current_down_reason" field.

func CurrentDownReasonEqualFold

func CurrentDownReasonEqualFold(v string) predicate.Monitor

CurrentDownReasonEqualFold applies the EqualFold predicate on the "current_down_reason" field.

func CurrentDownReasonGT

func CurrentDownReasonGT(v string) predicate.Monitor

CurrentDownReasonGT applies the GT predicate on the "current_down_reason" field.

func CurrentDownReasonGTE

func CurrentDownReasonGTE(v string) predicate.Monitor

CurrentDownReasonGTE applies the GTE predicate on the "current_down_reason" field.

func CurrentDownReasonHasPrefix

func CurrentDownReasonHasPrefix(v string) predicate.Monitor

CurrentDownReasonHasPrefix applies the HasPrefix predicate on the "current_down_reason" field.

func CurrentDownReasonHasSuffix

func CurrentDownReasonHasSuffix(v string) predicate.Monitor

CurrentDownReasonHasSuffix applies the HasSuffix predicate on the "current_down_reason" field.

func CurrentDownReasonIn

func CurrentDownReasonIn(vs ...string) predicate.Monitor

CurrentDownReasonIn applies the In predicate on the "current_down_reason" field.

func CurrentDownReasonLT

func CurrentDownReasonLT(v string) predicate.Monitor

CurrentDownReasonLT applies the LT predicate on the "current_down_reason" field.

func CurrentDownReasonLTE

func CurrentDownReasonLTE(v string) predicate.Monitor

CurrentDownReasonLTE applies the LTE predicate on the "current_down_reason" field.

func CurrentDownReasonNEQ

func CurrentDownReasonNEQ(v string) predicate.Monitor

CurrentDownReasonNEQ applies the NEQ predicate on the "current_down_reason" field.

func CurrentDownReasonNotIn

func CurrentDownReasonNotIn(vs ...string) predicate.Monitor

CurrentDownReasonNotIn applies the NotIn predicate on the "current_down_reason" field.

func Description

func Description(v string) predicate.Monitor

Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.

func DescriptionContains

func DescriptionContains(v string) predicate.Monitor

DescriptionContains applies the Contains predicate on the "description" field.

func DescriptionContainsFold

func DescriptionContainsFold(v string) predicate.Monitor

DescriptionContainsFold applies the ContainsFold predicate on the "description" field.

func DescriptionEQ

func DescriptionEQ(v string) predicate.Monitor

DescriptionEQ applies the EQ predicate on the "description" field.

func DescriptionEqualFold

func DescriptionEqualFold(v string) predicate.Monitor

DescriptionEqualFold applies the EqualFold predicate on the "description" field.

func DescriptionGT

func DescriptionGT(v string) predicate.Monitor

DescriptionGT applies the GT predicate on the "description" field.

func DescriptionGTE

func DescriptionGTE(v string) predicate.Monitor

DescriptionGTE applies the GTE predicate on the "description" field.

func DescriptionHasPrefix

func DescriptionHasPrefix(v string) predicate.Monitor

DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.

func DescriptionHasSuffix

func DescriptionHasSuffix(v string) predicate.Monitor

DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.

func DescriptionIn

func DescriptionIn(vs ...string) predicate.Monitor

DescriptionIn applies the In predicate on the "description" field.

func DescriptionLT

func DescriptionLT(v string) predicate.Monitor

DescriptionLT applies the LT predicate on the "description" field.

func DescriptionLTE

func DescriptionLTE(v string) predicate.Monitor

DescriptionLTE applies the LTE predicate on the "description" field.

func DescriptionNEQ

func DescriptionNEQ(v string) predicate.Monitor

DescriptionNEQ applies the NEQ predicate on the "description" field.

func DescriptionNotIn

func DescriptionNotIn(vs ...string) predicate.Monitor

DescriptionNotIn applies the NotIn predicate on the "description" field.

func FailureCount

func FailureCount(v int) predicate.Monitor

FailureCount applies equality check predicate on the "failure_count" field. It's identical to FailureCountEQ.

func FailureCountEQ

func FailureCountEQ(v int) predicate.Monitor

FailureCountEQ applies the EQ predicate on the "failure_count" field.

func FailureCountGT

func FailureCountGT(v int) predicate.Monitor

FailureCountGT applies the GT predicate on the "failure_count" field.

func FailureCountGTE

func FailureCountGTE(v int) predicate.Monitor

FailureCountGTE applies the GTE predicate on the "failure_count" field.

func FailureCountIn

func FailureCountIn(vs ...int) predicate.Monitor

FailureCountIn applies the In predicate on the "failure_count" field.

func FailureCountLT

func FailureCountLT(v int) predicate.Monitor

FailureCountLT applies the LT predicate on the "failure_count" field.

func FailureCountLTE

func FailureCountLTE(v int) predicate.Monitor

FailureCountLTE applies the LTE predicate on the "failure_count" field.

func FailureCountNEQ

func FailureCountNEQ(v int) predicate.Monitor

FailureCountNEQ applies the NEQ predicate on the "failure_count" field.

func FailureCountNotIn

func FailureCountNotIn(vs ...int) predicate.Monitor

FailureCountNotIn applies the NotIn predicate on the "failure_count" field.

func FailureThreshold

func FailureThreshold(v int) predicate.Monitor

FailureThreshold applies equality check predicate on the "failure_threshold" field. It's identical to FailureThresholdEQ.

func FailureThresholdEQ

func FailureThresholdEQ(v int) predicate.Monitor

FailureThresholdEQ applies the EQ predicate on the "failure_threshold" field.

func FailureThresholdGT

func FailureThresholdGT(v int) predicate.Monitor

FailureThresholdGT applies the GT predicate on the "failure_threshold" field.

func FailureThresholdGTE

func FailureThresholdGTE(v int) predicate.Monitor

FailureThresholdGTE applies the GTE predicate on the "failure_threshold" field.

func FailureThresholdIn

func FailureThresholdIn(vs ...int) predicate.Monitor

FailureThresholdIn applies the In predicate on the "failure_threshold" field.

func FailureThresholdLT

func FailureThresholdLT(v int) predicate.Monitor

FailureThresholdLT applies the LT predicate on the "failure_threshold" field.

func FailureThresholdLTE

func FailureThresholdLTE(v int) predicate.Monitor

FailureThresholdLTE applies the LTE predicate on the "failure_threshold" field.

func FailureThresholdNEQ

func FailureThresholdNEQ(v int) predicate.Monitor

FailureThresholdNEQ applies the NEQ predicate on the "failure_threshold" field.

func FailureThresholdNotIn

func FailureThresholdNotIn(vs ...int) predicate.Monitor

FailureThresholdNotIn applies the NotIn predicate on the "failure_threshold" field.

func HasAlertChannels

func HasAlertChannels() predicate.Monitor

HasAlertChannels applies the HasEdge predicate on the "alert_channels" edge.

func HasAlertChannelsWith

func HasAlertChannelsWith(preds ...predicate.AlertChannel) predicate.Monitor

HasAlertChannelsWith applies the HasEdge predicate on the "alert_channels" edge with a given conditions (other predicates).

func ID

func ID(id string) predicate.Monitor

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id string) predicate.Monitor

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id string) predicate.Monitor

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id string) predicate.Monitor

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.Monitor

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id string) predicate.Monitor

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id string) predicate.Monitor

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id string) predicate.Monitor

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.Monitor

IDNotIn applies the NotIn predicate on the ID field.

func IntervalSeconds

func IntervalSeconds(v int) predicate.Monitor

IntervalSeconds applies equality check predicate on the "interval_seconds" field. It's identical to IntervalSecondsEQ.

func IntervalSecondsEQ

func IntervalSecondsEQ(v int) predicate.Monitor

IntervalSecondsEQ applies the EQ predicate on the "interval_seconds" field.

func IntervalSecondsGT

func IntervalSecondsGT(v int) predicate.Monitor

IntervalSecondsGT applies the GT predicate on the "interval_seconds" field.

func IntervalSecondsGTE

func IntervalSecondsGTE(v int) predicate.Monitor

IntervalSecondsGTE applies the GTE predicate on the "interval_seconds" field.

func IntervalSecondsIn

func IntervalSecondsIn(vs ...int) predicate.Monitor

IntervalSecondsIn applies the In predicate on the "interval_seconds" field.

func IntervalSecondsLT

func IntervalSecondsLT(v int) predicate.Monitor

IntervalSecondsLT applies the LT predicate on the "interval_seconds" field.

func IntervalSecondsLTE

func IntervalSecondsLTE(v int) predicate.Monitor

IntervalSecondsLTE applies the LTE predicate on the "interval_seconds" field.

func IntervalSecondsNEQ

func IntervalSecondsNEQ(v int) predicate.Monitor

IntervalSecondsNEQ applies the NEQ predicate on the "interval_seconds" field.

func IntervalSecondsNotIn

func IntervalSecondsNotIn(vs ...int) predicate.Monitor

IntervalSecondsNotIn applies the NotIn predicate on the "interval_seconds" field.

func LastCheckedAt

func LastCheckedAt(v time.Time) predicate.Monitor

LastCheckedAt applies equality check predicate on the "last_checked_at" field. It's identical to LastCheckedAtEQ.

func LastCheckedAtEQ

func LastCheckedAtEQ(v time.Time) predicate.Monitor

LastCheckedAtEQ applies the EQ predicate on the "last_checked_at" field.

func LastCheckedAtGT

func LastCheckedAtGT(v time.Time) predicate.Monitor

LastCheckedAtGT applies the GT predicate on the "last_checked_at" field.

func LastCheckedAtGTE

func LastCheckedAtGTE(v time.Time) predicate.Monitor

LastCheckedAtGTE applies the GTE predicate on the "last_checked_at" field.

func LastCheckedAtIn

func LastCheckedAtIn(vs ...time.Time) predicate.Monitor

LastCheckedAtIn applies the In predicate on the "last_checked_at" field.

func LastCheckedAtIsNil

func LastCheckedAtIsNil() predicate.Monitor

LastCheckedAtIsNil applies the IsNil predicate on the "last_checked_at" field.

func LastCheckedAtLT

func LastCheckedAtLT(v time.Time) predicate.Monitor

LastCheckedAtLT applies the LT predicate on the "last_checked_at" field.

func LastCheckedAtLTE

func LastCheckedAtLTE(v time.Time) predicate.Monitor

LastCheckedAtLTE applies the LTE predicate on the "last_checked_at" field.

func LastCheckedAtNEQ

func LastCheckedAtNEQ(v time.Time) predicate.Monitor

LastCheckedAtNEQ applies the NEQ predicate on the "last_checked_at" field.

func LastCheckedAtNotIn

func LastCheckedAtNotIn(vs ...time.Time) predicate.Monitor

LastCheckedAtNotIn applies the NotIn predicate on the "last_checked_at" field.

func LastCheckedAtNotNil

func LastCheckedAtNotNil() predicate.Monitor

LastCheckedAtNotNil applies the NotNil predicate on the "last_checked_at" field.

func MonitorType

func MonitorType(v string) predicate.Monitor

MonitorType applies equality check predicate on the "monitor_type" field. It's identical to MonitorTypeEQ.

func MonitorTypeContains

func MonitorTypeContains(v string) predicate.Monitor

MonitorTypeContains applies the Contains predicate on the "monitor_type" field.

func MonitorTypeContainsFold

func MonitorTypeContainsFold(v string) predicate.Monitor

MonitorTypeContainsFold applies the ContainsFold predicate on the "monitor_type" field.

func MonitorTypeEQ

func MonitorTypeEQ(v string) predicate.Monitor

MonitorTypeEQ applies the EQ predicate on the "monitor_type" field.

func MonitorTypeEqualFold

func MonitorTypeEqualFold(v string) predicate.Monitor

MonitorTypeEqualFold applies the EqualFold predicate on the "monitor_type" field.

func MonitorTypeGT

func MonitorTypeGT(v string) predicate.Monitor

MonitorTypeGT applies the GT predicate on the "monitor_type" field.

func MonitorTypeGTE

func MonitorTypeGTE(v string) predicate.Monitor

MonitorTypeGTE applies the GTE predicate on the "monitor_type" field.

func MonitorTypeHasPrefix

func MonitorTypeHasPrefix(v string) predicate.Monitor

MonitorTypeHasPrefix applies the HasPrefix predicate on the "monitor_type" field.

func MonitorTypeHasSuffix

func MonitorTypeHasSuffix(v string) predicate.Monitor

MonitorTypeHasSuffix applies the HasSuffix predicate on the "monitor_type" field.

func MonitorTypeIn

func MonitorTypeIn(vs ...string) predicate.Monitor

MonitorTypeIn applies the In predicate on the "monitor_type" field.

func MonitorTypeLT

func MonitorTypeLT(v string) predicate.Monitor

MonitorTypeLT applies the LT predicate on the "monitor_type" field.

func MonitorTypeLTE

func MonitorTypeLTE(v string) predicate.Monitor

MonitorTypeLTE applies the LTE predicate on the "monitor_type" field.

func MonitorTypeNEQ

func MonitorTypeNEQ(v string) predicate.Monitor

MonitorTypeNEQ applies the NEQ predicate on the "monitor_type" field.

func MonitorTypeNotIn

func MonitorTypeNotIn(vs ...string) predicate.Monitor

MonitorTypeNotIn applies the NotIn predicate on the "monitor_type" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Monitor) predicate.Monitor

Or groups predicates with the OR operator between them.

func Paused

func Paused(v bool) predicate.Monitor

Paused applies equality check predicate on the "paused" field. It's identical to PausedEQ.

func PausedEQ

func PausedEQ(v bool) predicate.Monitor

PausedEQ applies the EQ predicate on the "paused" field.

func PausedNEQ

func PausedNEQ(v bool) predicate.Monitor

PausedNEQ applies the NEQ predicate on the "paused" field.

func Silenced

func Silenced(v bool) predicate.Monitor

Silenced applies equality check predicate on the "silenced" field. It's identical to SilencedEQ.

func SilencedEQ

func SilencedEQ(v bool) predicate.Monitor

SilencedEQ applies the EQ predicate on the "silenced" field.

func SilencedNEQ

func SilencedNEQ(v bool) predicate.Monitor

SilencedNEQ applies the NEQ predicate on the "silenced" field.

func Status

func Status(v string) predicate.Monitor

Status applies equality check predicate on the "status" field. It's identical to StatusEQ.

func StatusContains

func StatusContains(v string) predicate.Monitor

StatusContains applies the Contains predicate on the "status" field.

func StatusContainsFold

func StatusContainsFold(v string) predicate.Monitor

StatusContainsFold applies the ContainsFold predicate on the "status" field.

func StatusEQ

func StatusEQ(v string) predicate.Monitor

StatusEQ applies the EQ predicate on the "status" field.

func StatusEqualFold

func StatusEqualFold(v string) predicate.Monitor

StatusEqualFold applies the EqualFold predicate on the "status" field.

func StatusGT

func StatusGT(v string) predicate.Monitor

StatusGT applies the GT predicate on the "status" field.

func StatusGTE

func StatusGTE(v string) predicate.Monitor

StatusGTE applies the GTE predicate on the "status" field.

func StatusHasPrefix

func StatusHasPrefix(v string) predicate.Monitor

StatusHasPrefix applies the HasPrefix predicate on the "status" field.

func StatusHasSuffix

func StatusHasSuffix(v string) predicate.Monitor

StatusHasSuffix applies the HasSuffix predicate on the "status" field.

func StatusIn

func StatusIn(vs ...string) predicate.Monitor

StatusIn applies the In predicate on the "status" field.

func StatusLT

func StatusLT(v string) predicate.Monitor

StatusLT applies the LT predicate on the "status" field.

func StatusLTE

func StatusLTE(v string) predicate.Monitor

StatusLTE applies the LTE predicate on the "status" field.

func StatusLastChangedAt

func StatusLastChangedAt(v time.Time) predicate.Monitor

StatusLastChangedAt applies equality check predicate on the "status_last_changed_at" field. It's identical to StatusLastChangedAtEQ.

func StatusLastChangedAtEQ

func StatusLastChangedAtEQ(v time.Time) predicate.Monitor

StatusLastChangedAtEQ applies the EQ predicate on the "status_last_changed_at" field.

func StatusLastChangedAtGT

func StatusLastChangedAtGT(v time.Time) predicate.Monitor

StatusLastChangedAtGT applies the GT predicate on the "status_last_changed_at" field.

func StatusLastChangedAtGTE

func StatusLastChangedAtGTE(v time.Time) predicate.Monitor

StatusLastChangedAtGTE applies the GTE predicate on the "status_last_changed_at" field.

func StatusLastChangedAtIn

func StatusLastChangedAtIn(vs ...time.Time) predicate.Monitor

StatusLastChangedAtIn applies the In predicate on the "status_last_changed_at" field.

func StatusLastChangedAtLT

func StatusLastChangedAtLT(v time.Time) predicate.Monitor

StatusLastChangedAtLT applies the LT predicate on the "status_last_changed_at" field.

func StatusLastChangedAtLTE

func StatusLastChangedAtLTE(v time.Time) predicate.Monitor

StatusLastChangedAtLTE applies the LTE predicate on the "status_last_changed_at" field.

func StatusLastChangedAtNEQ

func StatusLastChangedAtNEQ(v time.Time) predicate.Monitor

StatusLastChangedAtNEQ applies the NEQ predicate on the "status_last_changed_at" field.

func StatusLastChangedAtNotIn

func StatusLastChangedAtNotIn(vs ...time.Time) predicate.Monitor

StatusLastChangedAtNotIn applies the NotIn predicate on the "status_last_changed_at" field.

func StatusNEQ

func StatusNEQ(v string) predicate.Monitor

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...string) predicate.Monitor

StatusNotIn applies the NotIn predicate on the "status" field.

func SuccessCount

func SuccessCount(v int) predicate.Monitor

SuccessCount applies equality check predicate on the "success_count" field. It's identical to SuccessCountEQ.

func SuccessCountEQ

func SuccessCountEQ(v int) predicate.Monitor

SuccessCountEQ applies the EQ predicate on the "success_count" field.

func SuccessCountGT

func SuccessCountGT(v int) predicate.Monitor

SuccessCountGT applies the GT predicate on the "success_count" field.

func SuccessCountGTE

func SuccessCountGTE(v int) predicate.Monitor

SuccessCountGTE applies the GTE predicate on the "success_count" field.

func SuccessCountIn

func SuccessCountIn(vs ...int) predicate.Monitor

SuccessCountIn applies the In predicate on the "success_count" field.

func SuccessCountLT

func SuccessCountLT(v int) predicate.Monitor

SuccessCountLT applies the LT predicate on the "success_count" field.

func SuccessCountLTE

func SuccessCountLTE(v int) predicate.Monitor

SuccessCountLTE applies the LTE predicate on the "success_count" field.

func SuccessCountNEQ

func SuccessCountNEQ(v int) predicate.Monitor

SuccessCountNEQ applies the NEQ predicate on the "success_count" field.

func SuccessCountNotIn

func SuccessCountNotIn(vs ...int) predicate.Monitor

SuccessCountNotIn applies the NotIn predicate on the "success_count" field.

func SuccessThreshold

func SuccessThreshold(v int) predicate.Monitor

SuccessThreshold applies equality check predicate on the "success_threshold" field. It's identical to SuccessThresholdEQ.

func SuccessThresholdEQ

func SuccessThresholdEQ(v int) predicate.Monitor

SuccessThresholdEQ applies the EQ predicate on the "success_threshold" field.

func SuccessThresholdGT

func SuccessThresholdGT(v int) predicate.Monitor

SuccessThresholdGT applies the GT predicate on the "success_threshold" field.

func SuccessThresholdGTE

func SuccessThresholdGTE(v int) predicate.Monitor

SuccessThresholdGTE applies the GTE predicate on the "success_threshold" field.

func SuccessThresholdIn

func SuccessThresholdIn(vs ...int) predicate.Monitor

SuccessThresholdIn applies the In predicate on the "success_threshold" field.

func SuccessThresholdLT

func SuccessThresholdLT(v int) predicate.Monitor

SuccessThresholdLT applies the LT predicate on the "success_threshold" field.

func SuccessThresholdLTE

func SuccessThresholdLTE(v int) predicate.Monitor

SuccessThresholdLTE applies the LTE predicate on the "success_threshold" field.

func SuccessThresholdNEQ

func SuccessThresholdNEQ(v int) predicate.Monitor

SuccessThresholdNEQ applies the NEQ predicate on the "success_threshold" field.

func SuccessThresholdNotIn

func SuccessThresholdNotIn(vs ...int) predicate.Monitor

SuccessThresholdNotIn applies the NotIn predicate on the "success_threshold" field.

func TagsIsNil

func TagsIsNil() predicate.Monitor

TagsIsNil applies the IsNil predicate on the "tags" field.

func TagsNotNil

func TagsNotNil() predicate.Monitor

TagsNotNil applies the NotNil predicate on the "tags" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Monitor

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Monitor

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Monitor

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Monitor

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Monitor

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Monitor

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Monitor

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Monitor

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Monitor

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

This section is empty.

Jump to