sink

package
v0.0.0-...-483b314 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 27, 2023 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the sink type in the database.
	Label = "sink"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldSinkType holds the string denoting the sink_type field in the database.
	FieldSinkType = "sink_type"
	// FieldConfig holds the string denoting the config field in the database.
	FieldConfig = "config"
	// Table holds the table name of the sink in the database.
	Table = "sinks"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// SinkTypeValidator is a validator for the "sink_type" field. It is called by the builders before save.
	SinkTypeValidator func(string) error
	// IDValidator is a validator for the "id" field. It is called by the builders before save.
	IDValidator func(string) error
)

Columns holds all SQL columns for sink fields.

Functions

func And

func And(predicates ...predicate.Sink) predicate.Sink

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.Sink

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Sink

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Sink

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Sink

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Sink

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Sink

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Sink

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Sink

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Sink

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func ID

func ID(id string) predicate.Sink

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id string) predicate.Sink

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id string) predicate.Sink

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id string) predicate.Sink

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.Sink

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id string) predicate.Sink

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id string) predicate.Sink

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id string) predicate.Sink

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.Sink

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Sink) predicate.Sink

Or groups predicates with the OR operator between them.

func SinkType

func SinkType(v string) predicate.Sink

SinkType applies equality check predicate on the "sink_type" field. It's identical to SinkTypeEQ.

func SinkTypeContains

func SinkTypeContains(v string) predicate.Sink

SinkTypeContains applies the Contains predicate on the "sink_type" field.

func SinkTypeContainsFold

func SinkTypeContainsFold(v string) predicate.Sink

SinkTypeContainsFold applies the ContainsFold predicate on the "sink_type" field.

func SinkTypeEQ

func SinkTypeEQ(v string) predicate.Sink

SinkTypeEQ applies the EQ predicate on the "sink_type" field.

func SinkTypeEqualFold

func SinkTypeEqualFold(v string) predicate.Sink

SinkTypeEqualFold applies the EqualFold predicate on the "sink_type" field.

func SinkTypeGT

func SinkTypeGT(v string) predicate.Sink

SinkTypeGT applies the GT predicate on the "sink_type" field.

func SinkTypeGTE

func SinkTypeGTE(v string) predicate.Sink

SinkTypeGTE applies the GTE predicate on the "sink_type" field.

func SinkTypeHasPrefix

func SinkTypeHasPrefix(v string) predicate.Sink

SinkTypeHasPrefix applies the HasPrefix predicate on the "sink_type" field.

func SinkTypeHasSuffix

func SinkTypeHasSuffix(v string) predicate.Sink

SinkTypeHasSuffix applies the HasSuffix predicate on the "sink_type" field.

func SinkTypeIn

func SinkTypeIn(vs ...string) predicate.Sink

SinkTypeIn applies the In predicate on the "sink_type" field.

func SinkTypeLT

func SinkTypeLT(v string) predicate.Sink

SinkTypeLT applies the LT predicate on the "sink_type" field.

func SinkTypeLTE

func SinkTypeLTE(v string) predicate.Sink

SinkTypeLTE applies the LTE predicate on the "sink_type" field.

func SinkTypeNEQ

func SinkTypeNEQ(v string) predicate.Sink

SinkTypeNEQ applies the NEQ predicate on the "sink_type" field.

func SinkTypeNotIn

func SinkTypeNotIn(vs ...string) predicate.Sink

SinkTypeNotIn applies the NotIn predicate on the "sink_type" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Sink

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Sink

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Sink

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Sink

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Sink

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Sink

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Sink

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Sink

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Sink

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

This section is empty.

Jump to