Documentation
¶
Index ¶
- Constants
- Variables
- func APIKey(v string) predicate.User
- func APIKeyContains(v string) predicate.User
- func APIKeyContainsFold(v string) predicate.User
- func APIKeyEQ(v string) predicate.User
- func APIKeyEqualFold(v string) predicate.User
- func APIKeyGT(v string) predicate.User
- func APIKeyGTE(v string) predicate.User
- func APIKeyHasPrefix(v string) predicate.User
- func APIKeyHasSuffix(v string) predicate.User
- func APIKeyIn(vs ...string) predicate.User
- func APIKeyLT(v string) predicate.User
- func APIKeyLTE(v string) predicate.User
- func APIKeyNEQ(v string) predicate.User
- func APIKeyNotIn(vs ...string) predicate.User
- func And(predicates ...predicate.User) predicate.User
- func CreatedAt(v time.Time) predicate.User
- func CreatedAtEQ(v time.Time) predicate.User
- func CreatedAtGT(v time.Time) predicate.User
- func CreatedAtGTE(v time.Time) predicate.User
- func CreatedAtIn(vs ...time.Time) predicate.User
- func CreatedAtLT(v time.Time) predicate.User
- func CreatedAtLTE(v time.Time) predicate.User
- func CreatedAtNEQ(v time.Time) predicate.User
- func CreatedAtNotIn(vs ...time.Time) predicate.User
- func ID(id string) predicate.User
- func IDEQ(id string) predicate.User
- func IDGT(id string) predicate.User
- func IDGTE(id string) predicate.User
- func IDIn(ids ...string) predicate.User
- func IDLT(id string) predicate.User
- func IDLTE(id string) predicate.User
- func IDNEQ(id string) predicate.User
- func IDNotIn(ids ...string) predicate.User
- func Locked(v bool) predicate.User
- func LockedEQ(v bool) predicate.User
- func LockedNEQ(v bool) predicate.User
- func LockedUntil(v time.Time) predicate.User
- func LockedUntilEQ(v time.Time) predicate.User
- func LockedUntilGT(v time.Time) predicate.User
- func LockedUntilGTE(v time.Time) predicate.User
- func LockedUntilIn(vs ...time.Time) predicate.User
- func LockedUntilIsNil() predicate.User
- func LockedUntilLT(v time.Time) predicate.User
- func LockedUntilLTE(v time.Time) predicate.User
- func LockedUntilNEQ(v time.Time) predicate.User
- func LockedUntilNotIn(vs ...time.Time) predicate.User
- func LockedUntilNotNil() predicate.User
- func Not(p predicate.User) predicate.User
- func Or(predicates ...predicate.User) predicate.User
- func Role(v string) predicate.User
- func RoleContains(v string) predicate.User
- func RoleContainsFold(v string) predicate.User
- func RoleEQ(v string) predicate.User
- func RoleEqualFold(v string) predicate.User
- func RoleGT(v string) predicate.User
- func RoleGTE(v string) predicate.User
- func RoleHasPrefix(v string) predicate.User
- func RoleHasSuffix(v string) predicate.User
- func RoleIn(vs ...string) predicate.User
- func RoleLT(v string) predicate.User
- func RoleLTE(v string) predicate.User
- func RoleNEQ(v string) predicate.User
- func RoleNotIn(vs ...string) predicate.User
- func UpdatedAt(v time.Time) predicate.User
- func UpdatedAtEQ(v time.Time) predicate.User
- func UpdatedAtGT(v time.Time) predicate.User
- func UpdatedAtGTE(v time.Time) predicate.User
- func UpdatedAtIn(vs ...time.Time) predicate.User
- func UpdatedAtLT(v time.Time) predicate.User
- func UpdatedAtLTE(v time.Time) predicate.User
- func UpdatedAtNEQ(v time.Time) predicate.User
- func UpdatedAtNotIn(vs ...time.Time) predicate.User
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the user type in the database. Label = "user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldAPIKey holds the string denoting the api_key field in the database. FieldAPIKey = "api_key" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldRole holds the string denoting the role field in the database. FieldRole = "role" // FieldLocked holds the string denoting the locked field in the database. FieldLocked = "locked" // FieldLockedUntil holds the string denoting the locked_until field in the database. FieldLockedUntil = "locked_until" // Table holds the table name of the user in the database. Table = "users" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultRole holds the default value on creation for the "role" field. DefaultRole string // DefaultLocked holds the default value on creation for the "locked" field. DefaultLocked bool // IDValidator is a validator for the "id" field. It is called by the builders before save. IDValidator func(string) error )
var Columns = []string{ FieldID, FieldAPIKey, FieldCreatedAt, FieldUpdatedAt, FieldRole, FieldLocked, FieldLockedUntil, }
Columns holds all SQL columns for user fields.
Functions ¶
func APIKey ¶
APIKey applies equality check predicate on the "api_key" field. It's identical to APIKeyEQ.
func APIKeyContains ¶
APIKeyContains applies the Contains predicate on the "api_key" field.
func APIKeyContainsFold ¶
APIKeyContainsFold applies the ContainsFold predicate on the "api_key" field.
func APIKeyEqualFold ¶
APIKeyEqualFold applies the EqualFold predicate on the "api_key" field.
func APIKeyHasPrefix ¶
APIKeyHasPrefix applies the HasPrefix predicate on the "api_key" field.
func APIKeyHasSuffix ¶
APIKeyHasSuffix applies the HasSuffix predicate on the "api_key" field.
func APIKeyNotIn ¶
APIKeyNotIn applies the NotIn predicate on the "api_key" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Locked ¶
Locked applies equality check predicate on the "locked" field. It's identical to LockedEQ.
func LockedUntil ¶
LockedUntil applies equality check predicate on the "locked_until" field. It's identical to LockedUntilEQ.
func LockedUntilEQ ¶
LockedUntilEQ applies the EQ predicate on the "locked_until" field.
func LockedUntilGT ¶
LockedUntilGT applies the GT predicate on the "locked_until" field.
func LockedUntilGTE ¶
LockedUntilGTE applies the GTE predicate on the "locked_until" field.
func LockedUntilIn ¶
LockedUntilIn applies the In predicate on the "locked_until" field.
func LockedUntilIsNil ¶
LockedUntilIsNil applies the IsNil predicate on the "locked_until" field.
func LockedUntilLT ¶
LockedUntilLT applies the LT predicate on the "locked_until" field.
func LockedUntilLTE ¶
LockedUntilLTE applies the LTE predicate on the "locked_until" field.
func LockedUntilNEQ ¶
LockedUntilNEQ applies the NEQ predicate on the "locked_until" field.
func LockedUntilNotIn ¶
LockedUntilNotIn applies the NotIn predicate on the "locked_until" field.
func LockedUntilNotNil ¶
LockedUntilNotNil applies the NotNil predicate on the "locked_until" field.
func RoleContains ¶
RoleContains applies the Contains predicate on the "role" field.
func RoleContainsFold ¶
RoleContainsFold applies the ContainsFold predicate on the "role" field.
func RoleEqualFold ¶
RoleEqualFold applies the EqualFold predicate on the "role" field.
func RoleHasPrefix ¶
RoleHasPrefix applies the HasPrefix predicate on the "role" field.
func RoleHasSuffix ¶
RoleHasSuffix applies the HasSuffix predicate on the "role" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.