Documentation
¶
Index ¶
- Constants
- Variables
- func AlertChannelType(v string) predicate.AlertChannel
- func AlertChannelTypeContains(v string) predicate.AlertChannel
- func AlertChannelTypeContainsFold(v string) predicate.AlertChannel
- func AlertChannelTypeEQ(v string) predicate.AlertChannel
- func AlertChannelTypeEqualFold(v string) predicate.AlertChannel
- func AlertChannelTypeGT(v string) predicate.AlertChannel
- func AlertChannelTypeGTE(v string) predicate.AlertChannel
- func AlertChannelTypeHasPrefix(v string) predicate.AlertChannel
- func AlertChannelTypeHasSuffix(v string) predicate.AlertChannel
- func AlertChannelTypeIn(vs ...string) predicate.AlertChannel
- func AlertChannelTypeLT(v string) predicate.AlertChannel
- func AlertChannelTypeLTE(v string) predicate.AlertChannel
- func AlertChannelTypeNEQ(v string) predicate.AlertChannel
- func AlertChannelTypeNotIn(vs ...string) predicate.AlertChannel
- func And(predicates ...predicate.AlertChannel) predicate.AlertChannel
- func CreatedAt(v time.Time) predicate.AlertChannel
- func CreatedAtEQ(v time.Time) predicate.AlertChannel
- func CreatedAtGT(v time.Time) predicate.AlertChannel
- func CreatedAtGTE(v time.Time) predicate.AlertChannel
- func CreatedAtIn(vs ...time.Time) predicate.AlertChannel
- func CreatedAtLT(v time.Time) predicate.AlertChannel
- func CreatedAtLTE(v time.Time) predicate.AlertChannel
- func CreatedAtNEQ(v time.Time) predicate.AlertChannel
- func CreatedAtNotIn(vs ...time.Time) predicate.AlertChannel
- func HasMonitors() predicate.AlertChannel
- func HasMonitorsWith(preds ...predicate.Monitor) predicate.AlertChannel
- func ID(id string) predicate.AlertChannel
- func IDEQ(id string) predicate.AlertChannel
- func IDGT(id string) predicate.AlertChannel
- func IDGTE(id string) predicate.AlertChannel
- func IDIn(ids ...string) predicate.AlertChannel
- func IDLT(id string) predicate.AlertChannel
- func IDLTE(id string) predicate.AlertChannel
- func IDNEQ(id string) predicate.AlertChannel
- func IDNotIn(ids ...string) predicate.AlertChannel
- func Not(p predicate.AlertChannel) predicate.AlertChannel
- func Or(predicates ...predicate.AlertChannel) predicate.AlertChannel
- func UpdatedAt(v time.Time) predicate.AlertChannel
- func UpdatedAtEQ(v time.Time) predicate.AlertChannel
- func UpdatedAtGT(v time.Time) predicate.AlertChannel
- func UpdatedAtGTE(v time.Time) predicate.AlertChannel
- func UpdatedAtIn(vs ...time.Time) predicate.AlertChannel
- func UpdatedAtLT(v time.Time) predicate.AlertChannel
- func UpdatedAtLTE(v time.Time) predicate.AlertChannel
- func UpdatedAtNEQ(v time.Time) predicate.AlertChannel
- func UpdatedAtNotIn(vs ...time.Time) predicate.AlertChannel
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the alertchannel type in the database. Label = "alert_channel" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldAlertChannelType holds the string denoting the alert_channel_type field in the database. FieldAlertChannelType = "alert_channel_type" // FieldConfig holds the string denoting the config field in the database. FieldConfig = "config" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeMonitors holds the string denoting the monitors edge name in mutations. EdgeMonitors = "monitors" // Table holds the table name of the alertchannel in the database. Table = "alert_channels" // MonitorsTable is the table that holds the monitors relation/edge. The primary key declared below. MonitorsTable = "alert_channel_monitors" // MonitorsInverseTable is the table name for the Monitor entity. // It exists in this package in order to avoid circular dependency with the "monitor" package. MonitorsInverseTable = "monitors" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // IDValidator is a validator for the "id" field. It is called by the builders before save. IDValidator func(string) error )
var Columns = []string{ FieldID, FieldAlertChannelType, FieldConfig, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for alertchannel fields.
var ( // MonitorsPrimaryKey and MonitorsColumn2 are the table columns denoting the // primary key for the monitors relation (M2M). MonitorsPrimaryKey = []string{"alert_channel_id", "monitor_id"} )
Functions ¶
func AlertChannelType ¶
func AlertChannelType(v string) predicate.AlertChannel
AlertChannelType applies equality check predicate on the "alert_channel_type" field. It's identical to AlertChannelTypeEQ.
func AlertChannelTypeContains ¶
func AlertChannelTypeContains(v string) predicate.AlertChannel
AlertChannelTypeContains applies the Contains predicate on the "alert_channel_type" field.
func AlertChannelTypeContainsFold ¶
func AlertChannelTypeContainsFold(v string) predicate.AlertChannel
AlertChannelTypeContainsFold applies the ContainsFold predicate on the "alert_channel_type" field.
func AlertChannelTypeEQ ¶
func AlertChannelTypeEQ(v string) predicate.AlertChannel
AlertChannelTypeEQ applies the EQ predicate on the "alert_channel_type" field.
func AlertChannelTypeEqualFold ¶
func AlertChannelTypeEqualFold(v string) predicate.AlertChannel
AlertChannelTypeEqualFold applies the EqualFold predicate on the "alert_channel_type" field.
func AlertChannelTypeGT ¶
func AlertChannelTypeGT(v string) predicate.AlertChannel
AlertChannelTypeGT applies the GT predicate on the "alert_channel_type" field.
func AlertChannelTypeGTE ¶
func AlertChannelTypeGTE(v string) predicate.AlertChannel
AlertChannelTypeGTE applies the GTE predicate on the "alert_channel_type" field.
func AlertChannelTypeHasPrefix ¶
func AlertChannelTypeHasPrefix(v string) predicate.AlertChannel
AlertChannelTypeHasPrefix applies the HasPrefix predicate on the "alert_channel_type" field.
func AlertChannelTypeHasSuffix ¶
func AlertChannelTypeHasSuffix(v string) predicate.AlertChannel
AlertChannelTypeHasSuffix applies the HasSuffix predicate on the "alert_channel_type" field.
func AlertChannelTypeIn ¶
func AlertChannelTypeIn(vs ...string) predicate.AlertChannel
AlertChannelTypeIn applies the In predicate on the "alert_channel_type" field.
func AlertChannelTypeLT ¶
func AlertChannelTypeLT(v string) predicate.AlertChannel
AlertChannelTypeLT applies the LT predicate on the "alert_channel_type" field.
func AlertChannelTypeLTE ¶
func AlertChannelTypeLTE(v string) predicate.AlertChannel
AlertChannelTypeLTE applies the LTE predicate on the "alert_channel_type" field.
func AlertChannelTypeNEQ ¶
func AlertChannelTypeNEQ(v string) predicate.AlertChannel
AlertChannelTypeNEQ applies the NEQ predicate on the "alert_channel_type" field.
func AlertChannelTypeNotIn ¶
func AlertChannelTypeNotIn(vs ...string) predicate.AlertChannel
AlertChannelTypeNotIn applies the NotIn predicate on the "alert_channel_type" field.
func And ¶
func And(predicates ...predicate.AlertChannel) predicate.AlertChannel
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.AlertChannel
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.AlertChannel
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.AlertChannel
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.AlertChannel
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.AlertChannel
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.AlertChannel
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.AlertChannel
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.AlertChannel
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.AlertChannel
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasMonitors ¶
func HasMonitors() predicate.AlertChannel
HasMonitors applies the HasEdge predicate on the "monitors" edge.
func HasMonitorsWith ¶
func HasMonitorsWith(preds ...predicate.Monitor) predicate.AlertChannel
HasMonitorsWith applies the HasEdge predicate on the "monitors" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id string) predicate.AlertChannel
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id string) predicate.AlertChannel
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id string) predicate.AlertChannel
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...string) predicate.AlertChannel
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id string) predicate.AlertChannel
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id string) predicate.AlertChannel
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id string) predicate.AlertChannel
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...string) predicate.AlertChannel
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.AlertChannel) predicate.AlertChannel
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.AlertChannel) predicate.AlertChannel
Or groups predicates with the OR operator between them.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.AlertChannel
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.AlertChannel
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.AlertChannel
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.AlertChannel
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.AlertChannel
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.AlertChannel
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.AlertChannel
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.AlertChannel
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.AlertChannel
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.