Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Monitor) predicate.Monitor
- func CreatedAt(v time.Time) predicate.Monitor
- func CreatedAtEQ(v time.Time) predicate.Monitor
- func CreatedAtGT(v time.Time) predicate.Monitor
- func CreatedAtGTE(v time.Time) predicate.Monitor
- func CreatedAtIn(vs ...time.Time) predicate.Monitor
- func CreatedAtLT(v time.Time) predicate.Monitor
- func CreatedAtLTE(v time.Time) predicate.Monitor
- func CreatedAtNEQ(v time.Time) predicate.Monitor
- func CreatedAtNotIn(vs ...time.Time) predicate.Monitor
- func CurrentDownReason(v string) predicate.Monitor
- func CurrentDownReasonContains(v string) predicate.Monitor
- func CurrentDownReasonContainsFold(v string) predicate.Monitor
- func CurrentDownReasonEQ(v string) predicate.Monitor
- func CurrentDownReasonEqualFold(v string) predicate.Monitor
- func CurrentDownReasonGT(v string) predicate.Monitor
- func CurrentDownReasonGTE(v string) predicate.Monitor
- func CurrentDownReasonHasPrefix(v string) predicate.Monitor
- func CurrentDownReasonHasSuffix(v string) predicate.Monitor
- func CurrentDownReasonIn(vs ...string) predicate.Monitor
- func CurrentDownReasonLT(v string) predicate.Monitor
- func CurrentDownReasonLTE(v string) predicate.Monitor
- func CurrentDownReasonNEQ(v string) predicate.Monitor
- func CurrentDownReasonNotIn(vs ...string) predicate.Monitor
- func Description(v string) predicate.Monitor
- func DescriptionContains(v string) predicate.Monitor
- func DescriptionContainsFold(v string) predicate.Monitor
- func DescriptionEQ(v string) predicate.Monitor
- func DescriptionEqualFold(v string) predicate.Monitor
- func DescriptionGT(v string) predicate.Monitor
- func DescriptionGTE(v string) predicate.Monitor
- func DescriptionHasPrefix(v string) predicate.Monitor
- func DescriptionHasSuffix(v string) predicate.Monitor
- func DescriptionIn(vs ...string) predicate.Monitor
- func DescriptionLT(v string) predicate.Monitor
- func DescriptionLTE(v string) predicate.Monitor
- func DescriptionNEQ(v string) predicate.Monitor
- func DescriptionNotIn(vs ...string) predicate.Monitor
- func FailureCount(v int) predicate.Monitor
- func FailureCountEQ(v int) predicate.Monitor
- func FailureCountGT(v int) predicate.Monitor
- func FailureCountGTE(v int) predicate.Monitor
- func FailureCountIn(vs ...int) predicate.Monitor
- func FailureCountLT(v int) predicate.Monitor
- func FailureCountLTE(v int) predicate.Monitor
- func FailureCountNEQ(v int) predicate.Monitor
- func FailureCountNotIn(vs ...int) predicate.Monitor
- func FailureThreshold(v int) predicate.Monitor
- func FailureThresholdEQ(v int) predicate.Monitor
- func FailureThresholdGT(v int) predicate.Monitor
- func FailureThresholdGTE(v int) predicate.Monitor
- func FailureThresholdIn(vs ...int) predicate.Monitor
- func FailureThresholdLT(v int) predicate.Monitor
- func FailureThresholdLTE(v int) predicate.Monitor
- func FailureThresholdNEQ(v int) predicate.Monitor
- func FailureThresholdNotIn(vs ...int) predicate.Monitor
- func HasAlertChannels() predicate.Monitor
- func HasAlertChannelsWith(preds ...predicate.AlertChannel) predicate.Monitor
- func ID(id string) predicate.Monitor
- func IDEQ(id string) predicate.Monitor
- func IDGT(id string) predicate.Monitor
- func IDGTE(id string) predicate.Monitor
- func IDIn(ids ...string) predicate.Monitor
- func IDLT(id string) predicate.Monitor
- func IDLTE(id string) predicate.Monitor
- func IDNEQ(id string) predicate.Monitor
- func IDNotIn(ids ...string) predicate.Monitor
- func IntervalSeconds(v int) predicate.Monitor
- func IntervalSecondsEQ(v int) predicate.Monitor
- func IntervalSecondsGT(v int) predicate.Monitor
- func IntervalSecondsGTE(v int) predicate.Monitor
- func IntervalSecondsIn(vs ...int) predicate.Monitor
- func IntervalSecondsLT(v int) predicate.Monitor
- func IntervalSecondsLTE(v int) predicate.Monitor
- func IntervalSecondsNEQ(v int) predicate.Monitor
- func IntervalSecondsNotIn(vs ...int) predicate.Monitor
- func LastCheckedAt(v time.Time) predicate.Monitor
- func LastCheckedAtEQ(v time.Time) predicate.Monitor
- func LastCheckedAtGT(v time.Time) predicate.Monitor
- func LastCheckedAtGTE(v time.Time) predicate.Monitor
- func LastCheckedAtIn(vs ...time.Time) predicate.Monitor
- func LastCheckedAtIsNil() predicate.Monitor
- func LastCheckedAtLT(v time.Time) predicate.Monitor
- func LastCheckedAtLTE(v time.Time) predicate.Monitor
- func LastCheckedAtNEQ(v time.Time) predicate.Monitor
- func LastCheckedAtNotIn(vs ...time.Time) predicate.Monitor
- func LastCheckedAtNotNil() predicate.Monitor
- func MonitorType(v string) predicate.Monitor
- func MonitorTypeContains(v string) predicate.Monitor
- func MonitorTypeContainsFold(v string) predicate.Monitor
- func MonitorTypeEQ(v string) predicate.Monitor
- func MonitorTypeEqualFold(v string) predicate.Monitor
- func MonitorTypeGT(v string) predicate.Monitor
- func MonitorTypeGTE(v string) predicate.Monitor
- func MonitorTypeHasPrefix(v string) predicate.Monitor
- func MonitorTypeHasSuffix(v string) predicate.Monitor
- func MonitorTypeIn(vs ...string) predicate.Monitor
- func MonitorTypeLT(v string) predicate.Monitor
- func MonitorTypeLTE(v string) predicate.Monitor
- func MonitorTypeNEQ(v string) predicate.Monitor
- func MonitorTypeNotIn(vs ...string) predicate.Monitor
- func Not(p predicate.Monitor) predicate.Monitor
- func Or(predicates ...predicate.Monitor) predicate.Monitor
- func Paused(v bool) predicate.Monitor
- func PausedEQ(v bool) predicate.Monitor
- func PausedNEQ(v bool) predicate.Monitor
- func Silenced(v bool) predicate.Monitor
- func SilencedEQ(v bool) predicate.Monitor
- func SilencedNEQ(v bool) predicate.Monitor
- func Status(v string) predicate.Monitor
- func StatusContains(v string) predicate.Monitor
- func StatusContainsFold(v string) predicate.Monitor
- func StatusEQ(v string) predicate.Monitor
- func StatusEqualFold(v string) predicate.Monitor
- func StatusGT(v string) predicate.Monitor
- func StatusGTE(v string) predicate.Monitor
- func StatusHasPrefix(v string) predicate.Monitor
- func StatusHasSuffix(v string) predicate.Monitor
- func StatusIn(vs ...string) predicate.Monitor
- func StatusLT(v string) predicate.Monitor
- func StatusLTE(v string) predicate.Monitor
- func StatusLastChangedAt(v time.Time) predicate.Monitor
- func StatusLastChangedAtEQ(v time.Time) predicate.Monitor
- func StatusLastChangedAtGT(v time.Time) predicate.Monitor
- func StatusLastChangedAtGTE(v time.Time) predicate.Monitor
- func StatusLastChangedAtIn(vs ...time.Time) predicate.Monitor
- func StatusLastChangedAtLT(v time.Time) predicate.Monitor
- func StatusLastChangedAtLTE(v time.Time) predicate.Monitor
- func StatusLastChangedAtNEQ(v time.Time) predicate.Monitor
- func StatusLastChangedAtNotIn(vs ...time.Time) predicate.Monitor
- func StatusNEQ(v string) predicate.Monitor
- func StatusNotIn(vs ...string) predicate.Monitor
- func SuccessCount(v int) predicate.Monitor
- func SuccessCountEQ(v int) predicate.Monitor
- func SuccessCountGT(v int) predicate.Monitor
- func SuccessCountGTE(v int) predicate.Monitor
- func SuccessCountIn(vs ...int) predicate.Monitor
- func SuccessCountLT(v int) predicate.Monitor
- func SuccessCountLTE(v int) predicate.Monitor
- func SuccessCountNEQ(v int) predicate.Monitor
- func SuccessCountNotIn(vs ...int) predicate.Monitor
- func SuccessThreshold(v int) predicate.Monitor
- func SuccessThresholdEQ(v int) predicate.Monitor
- func SuccessThresholdGT(v int) predicate.Monitor
- func SuccessThresholdGTE(v int) predicate.Monitor
- func SuccessThresholdIn(vs ...int) predicate.Monitor
- func SuccessThresholdLT(v int) predicate.Monitor
- func SuccessThresholdLTE(v int) predicate.Monitor
- func SuccessThresholdNEQ(v int) predicate.Monitor
- func SuccessThresholdNotIn(vs ...int) predicate.Monitor
- func TagsIsNil() predicate.Monitor
- func TagsNotNil() predicate.Monitor
- func UpdatedAt(v time.Time) predicate.Monitor
- func UpdatedAtEQ(v time.Time) predicate.Monitor
- func UpdatedAtGT(v time.Time) predicate.Monitor
- func UpdatedAtGTE(v time.Time) predicate.Monitor
- func UpdatedAtIn(vs ...time.Time) predicate.Monitor
- func UpdatedAtLT(v time.Time) predicate.Monitor
- func UpdatedAtLTE(v time.Time) predicate.Monitor
- func UpdatedAtNEQ(v time.Time) predicate.Monitor
- func UpdatedAtNotIn(vs ...time.Time) predicate.Monitor
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the monitor type in the database. Label = "monitor" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldDescription holds the string denoting the description field in the database. FieldDescription = "description" // FieldCurrentDownReason holds the string denoting the current_down_reason field in the database. FieldCurrentDownReason = "current_down_reason" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldLastCheckedAt holds the string denoting the last_checked_at field in the database. FieldLastCheckedAt = "last_checked_at" // FieldStatusLastChangedAt holds the string denoting the status_last_changed_at field in the database. FieldStatusLastChangedAt = "status_last_changed_at" // FieldMonitorType holds the string denoting the monitor_type field in the database. FieldMonitorType = "monitor_type" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldConfig holds the string denoting the config field in the database. FieldConfig = "config" // FieldIntervalSeconds holds the string denoting the interval_seconds field in the database. FieldIntervalSeconds = "interval_seconds" // FieldPaused holds the string denoting the paused field in the database. FieldPaused = "paused" // FieldFailureCount holds the string denoting the failure_count field in the database. FieldFailureCount = "failure_count" // FieldSuccessCount holds the string denoting the success_count field in the database. FieldSuccessCount = "success_count" // FieldSuccessThreshold holds the string denoting the success_threshold field in the database. FieldSuccessThreshold = "success_threshold" // FieldFailureThreshold holds the string denoting the failure_threshold field in the database. FieldFailureThreshold = "failure_threshold" // FieldTags holds the string denoting the tags field in the database. FieldTags = "tags" // FieldSilenced holds the string denoting the silenced field in the database. FieldSilenced = "silenced" // EdgeAlertChannels holds the string denoting the alert_channels edge name in mutations. EdgeAlertChannels = "alert_channels" // Table holds the table name of the monitor in the database. Table = "monitors" // AlertChannelsTable is the table that holds the alert_channels relation/edge. The primary key declared below. AlertChannelsTable = "alert_channel_monitors" // AlertChannelsInverseTable is the table name for the AlertChannel entity. // It exists in this package in order to avoid circular dependency with the "alertchannel" package. AlertChannelsInverseTable = "alert_channels" )
Variables ¶
var ( // DefaultDescription holds the default value on creation for the "description" field. DefaultDescription string // DefaultCurrentDownReason holds the default value on creation for the "current_down_reason" field. DefaultCurrentDownReason string // DefaultStatusLastChangedAt holds the default value on creation for the "status_last_changed_at" field. DefaultStatusLastChangedAt func() time.Time // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultIntervalSeconds holds the default value on creation for the "interval_seconds" field. DefaultIntervalSeconds int // DefaultPaused holds the default value on creation for the "paused" field. DefaultPaused bool // DefaultFailureCount holds the default value on creation for the "failure_count" field. DefaultFailureCount int // DefaultSuccessCount holds the default value on creation for the "success_count" field. DefaultSuccessCount int // DefaultSuccessThreshold holds the default value on creation for the "success_threshold" field. DefaultSuccessThreshold int // DefaultFailureThreshold holds the default value on creation for the "failure_threshold" field. DefaultFailureThreshold int // DefaultSilenced holds the default value on creation for the "silenced" field. DefaultSilenced bool // IDValidator is a validator for the "id" field. It is called by the builders before save. IDValidator func(string) error )
var ( // AlertChannelsPrimaryKey and AlertChannelsColumn2 are the table columns denoting the // primary key for the alert_channels relation (M2M). AlertChannelsPrimaryKey = []string{"alert_channel_id", "monitor_id"} )
var Columns = []string{ FieldID, FieldDescription, FieldCurrentDownReason, FieldStatus, FieldLastCheckedAt, FieldStatusLastChangedAt, FieldMonitorType, FieldCreatedAt, FieldUpdatedAt, FieldConfig, FieldIntervalSeconds, FieldPaused, FieldFailureCount, FieldSuccessCount, FieldSuccessThreshold, FieldFailureThreshold, FieldTags, FieldSilenced, }
Columns holds all SQL columns for monitor fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CurrentDownReason ¶
CurrentDownReason applies equality check predicate on the "current_down_reason" field. It's identical to CurrentDownReasonEQ.
func CurrentDownReasonContains ¶
CurrentDownReasonContains applies the Contains predicate on the "current_down_reason" field.
func CurrentDownReasonContainsFold ¶
CurrentDownReasonContainsFold applies the ContainsFold predicate on the "current_down_reason" field.
func CurrentDownReasonEQ ¶
CurrentDownReasonEQ applies the EQ predicate on the "current_down_reason" field.
func CurrentDownReasonEqualFold ¶
CurrentDownReasonEqualFold applies the EqualFold predicate on the "current_down_reason" field.
func CurrentDownReasonGT ¶
CurrentDownReasonGT applies the GT predicate on the "current_down_reason" field.
func CurrentDownReasonGTE ¶
CurrentDownReasonGTE applies the GTE predicate on the "current_down_reason" field.
func CurrentDownReasonHasPrefix ¶
CurrentDownReasonHasPrefix applies the HasPrefix predicate on the "current_down_reason" field.
func CurrentDownReasonHasSuffix ¶
CurrentDownReasonHasSuffix applies the HasSuffix predicate on the "current_down_reason" field.
func CurrentDownReasonIn ¶
CurrentDownReasonIn applies the In predicate on the "current_down_reason" field.
func CurrentDownReasonLT ¶
CurrentDownReasonLT applies the LT predicate on the "current_down_reason" field.
func CurrentDownReasonLTE ¶
CurrentDownReasonLTE applies the LTE predicate on the "current_down_reason" field.
func CurrentDownReasonNEQ ¶
CurrentDownReasonNEQ applies the NEQ predicate on the "current_down_reason" field.
func CurrentDownReasonNotIn ¶
CurrentDownReasonNotIn applies the NotIn predicate on the "current_down_reason" field.
func Description ¶
Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.
func DescriptionContains ¶
DescriptionContains applies the Contains predicate on the "description" field.
func DescriptionContainsFold ¶
DescriptionContainsFold applies the ContainsFold predicate on the "description" field.
func DescriptionEQ ¶
DescriptionEQ applies the EQ predicate on the "description" field.
func DescriptionEqualFold ¶
DescriptionEqualFold applies the EqualFold predicate on the "description" field.
func DescriptionGT ¶
DescriptionGT applies the GT predicate on the "description" field.
func DescriptionGTE ¶
DescriptionGTE applies the GTE predicate on the "description" field.
func DescriptionHasPrefix ¶
DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.
func DescriptionHasSuffix ¶
DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.
func DescriptionIn ¶
DescriptionIn applies the In predicate on the "description" field.
func DescriptionLT ¶
DescriptionLT applies the LT predicate on the "description" field.
func DescriptionLTE ¶
DescriptionLTE applies the LTE predicate on the "description" field.
func DescriptionNEQ ¶
DescriptionNEQ applies the NEQ predicate on the "description" field.
func DescriptionNotIn ¶
DescriptionNotIn applies the NotIn predicate on the "description" field.
func FailureCount ¶
FailureCount applies equality check predicate on the "failure_count" field. It's identical to FailureCountEQ.
func FailureCountEQ ¶
FailureCountEQ applies the EQ predicate on the "failure_count" field.
func FailureCountGT ¶
FailureCountGT applies the GT predicate on the "failure_count" field.
func FailureCountGTE ¶
FailureCountGTE applies the GTE predicate on the "failure_count" field.
func FailureCountIn ¶
FailureCountIn applies the In predicate on the "failure_count" field.
func FailureCountLT ¶
FailureCountLT applies the LT predicate on the "failure_count" field.
func FailureCountLTE ¶
FailureCountLTE applies the LTE predicate on the "failure_count" field.
func FailureCountNEQ ¶
FailureCountNEQ applies the NEQ predicate on the "failure_count" field.
func FailureCountNotIn ¶
FailureCountNotIn applies the NotIn predicate on the "failure_count" field.
func FailureThreshold ¶
FailureThreshold applies equality check predicate on the "failure_threshold" field. It's identical to FailureThresholdEQ.
func FailureThresholdEQ ¶
FailureThresholdEQ applies the EQ predicate on the "failure_threshold" field.
func FailureThresholdGT ¶
FailureThresholdGT applies the GT predicate on the "failure_threshold" field.
func FailureThresholdGTE ¶
FailureThresholdGTE applies the GTE predicate on the "failure_threshold" field.
func FailureThresholdIn ¶
FailureThresholdIn applies the In predicate on the "failure_threshold" field.
func FailureThresholdLT ¶
FailureThresholdLT applies the LT predicate on the "failure_threshold" field.
func FailureThresholdLTE ¶
FailureThresholdLTE applies the LTE predicate on the "failure_threshold" field.
func FailureThresholdNEQ ¶
FailureThresholdNEQ applies the NEQ predicate on the "failure_threshold" field.
func FailureThresholdNotIn ¶
FailureThresholdNotIn applies the NotIn predicate on the "failure_threshold" field.
func HasAlertChannels ¶
HasAlertChannels applies the HasEdge predicate on the "alert_channels" edge.
func HasAlertChannelsWith ¶
func HasAlertChannelsWith(preds ...predicate.AlertChannel) predicate.Monitor
HasAlertChannelsWith applies the HasEdge predicate on the "alert_channels" edge with a given conditions (other predicates).
func IntervalSeconds ¶
IntervalSeconds applies equality check predicate on the "interval_seconds" field. It's identical to IntervalSecondsEQ.
func IntervalSecondsEQ ¶
IntervalSecondsEQ applies the EQ predicate on the "interval_seconds" field.
func IntervalSecondsGT ¶
IntervalSecondsGT applies the GT predicate on the "interval_seconds" field.
func IntervalSecondsGTE ¶
IntervalSecondsGTE applies the GTE predicate on the "interval_seconds" field.
func IntervalSecondsIn ¶
IntervalSecondsIn applies the In predicate on the "interval_seconds" field.
func IntervalSecondsLT ¶
IntervalSecondsLT applies the LT predicate on the "interval_seconds" field.
func IntervalSecondsLTE ¶
IntervalSecondsLTE applies the LTE predicate on the "interval_seconds" field.
func IntervalSecondsNEQ ¶
IntervalSecondsNEQ applies the NEQ predicate on the "interval_seconds" field.
func IntervalSecondsNotIn ¶
IntervalSecondsNotIn applies the NotIn predicate on the "interval_seconds" field.
func LastCheckedAt ¶
LastCheckedAt applies equality check predicate on the "last_checked_at" field. It's identical to LastCheckedAtEQ.
func LastCheckedAtEQ ¶
LastCheckedAtEQ applies the EQ predicate on the "last_checked_at" field.
func LastCheckedAtGT ¶
LastCheckedAtGT applies the GT predicate on the "last_checked_at" field.
func LastCheckedAtGTE ¶
LastCheckedAtGTE applies the GTE predicate on the "last_checked_at" field.
func LastCheckedAtIn ¶
LastCheckedAtIn applies the In predicate on the "last_checked_at" field.
func LastCheckedAtIsNil ¶
LastCheckedAtIsNil applies the IsNil predicate on the "last_checked_at" field.
func LastCheckedAtLT ¶
LastCheckedAtLT applies the LT predicate on the "last_checked_at" field.
func LastCheckedAtLTE ¶
LastCheckedAtLTE applies the LTE predicate on the "last_checked_at" field.
func LastCheckedAtNEQ ¶
LastCheckedAtNEQ applies the NEQ predicate on the "last_checked_at" field.
func LastCheckedAtNotIn ¶
LastCheckedAtNotIn applies the NotIn predicate on the "last_checked_at" field.
func LastCheckedAtNotNil ¶
LastCheckedAtNotNil applies the NotNil predicate on the "last_checked_at" field.
func MonitorType ¶
MonitorType applies equality check predicate on the "monitor_type" field. It's identical to MonitorTypeEQ.
func MonitorTypeContains ¶
MonitorTypeContains applies the Contains predicate on the "monitor_type" field.
func MonitorTypeContainsFold ¶
MonitorTypeContainsFold applies the ContainsFold predicate on the "monitor_type" field.
func MonitorTypeEQ ¶
MonitorTypeEQ applies the EQ predicate on the "monitor_type" field.
func MonitorTypeEqualFold ¶
MonitorTypeEqualFold applies the EqualFold predicate on the "monitor_type" field.
func MonitorTypeGT ¶
MonitorTypeGT applies the GT predicate on the "monitor_type" field.
func MonitorTypeGTE ¶
MonitorTypeGTE applies the GTE predicate on the "monitor_type" field.
func MonitorTypeHasPrefix ¶
MonitorTypeHasPrefix applies the HasPrefix predicate on the "monitor_type" field.
func MonitorTypeHasSuffix ¶
MonitorTypeHasSuffix applies the HasSuffix predicate on the "monitor_type" field.
func MonitorTypeIn ¶
MonitorTypeIn applies the In predicate on the "monitor_type" field.
func MonitorTypeLT ¶
MonitorTypeLT applies the LT predicate on the "monitor_type" field.
func MonitorTypeLTE ¶
MonitorTypeLTE applies the LTE predicate on the "monitor_type" field.
func MonitorTypeNEQ ¶
MonitorTypeNEQ applies the NEQ predicate on the "monitor_type" field.
func MonitorTypeNotIn ¶
MonitorTypeNotIn applies the NotIn predicate on the "monitor_type" field.
func Paused ¶
Paused applies equality check predicate on the "paused" field. It's identical to PausedEQ.
func Silenced ¶
Silenced applies equality check predicate on the "silenced" field. It's identical to SilencedEQ.
func SilencedEQ ¶
SilencedEQ applies the EQ predicate on the "silenced" field.
func SilencedNEQ ¶
SilencedNEQ applies the NEQ predicate on the "silenced" field.
func Status ¶
Status applies equality check predicate on the "status" field. It's identical to StatusEQ.
func StatusContains ¶
StatusContains applies the Contains predicate on the "status" field.
func StatusContainsFold ¶
StatusContainsFold applies the ContainsFold predicate on the "status" field.
func StatusEqualFold ¶
StatusEqualFold applies the EqualFold predicate on the "status" field.
func StatusHasPrefix ¶
StatusHasPrefix applies the HasPrefix predicate on the "status" field.
func StatusHasSuffix ¶
StatusHasSuffix applies the HasSuffix predicate on the "status" field.
func StatusLastChangedAt ¶
StatusLastChangedAt applies equality check predicate on the "status_last_changed_at" field. It's identical to StatusLastChangedAtEQ.
func StatusLastChangedAtEQ ¶
StatusLastChangedAtEQ applies the EQ predicate on the "status_last_changed_at" field.
func StatusLastChangedAtGT ¶
StatusLastChangedAtGT applies the GT predicate on the "status_last_changed_at" field.
func StatusLastChangedAtGTE ¶
StatusLastChangedAtGTE applies the GTE predicate on the "status_last_changed_at" field.
func StatusLastChangedAtIn ¶
StatusLastChangedAtIn applies the In predicate on the "status_last_changed_at" field.
func StatusLastChangedAtLT ¶
StatusLastChangedAtLT applies the LT predicate on the "status_last_changed_at" field.
func StatusLastChangedAtLTE ¶
StatusLastChangedAtLTE applies the LTE predicate on the "status_last_changed_at" field.
func StatusLastChangedAtNEQ ¶
StatusLastChangedAtNEQ applies the NEQ predicate on the "status_last_changed_at" field.
func StatusLastChangedAtNotIn ¶
StatusLastChangedAtNotIn applies the NotIn predicate on the "status_last_changed_at" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func SuccessCount ¶
SuccessCount applies equality check predicate on the "success_count" field. It's identical to SuccessCountEQ.
func SuccessCountEQ ¶
SuccessCountEQ applies the EQ predicate on the "success_count" field.
func SuccessCountGT ¶
SuccessCountGT applies the GT predicate on the "success_count" field.
func SuccessCountGTE ¶
SuccessCountGTE applies the GTE predicate on the "success_count" field.
func SuccessCountIn ¶
SuccessCountIn applies the In predicate on the "success_count" field.
func SuccessCountLT ¶
SuccessCountLT applies the LT predicate on the "success_count" field.
func SuccessCountLTE ¶
SuccessCountLTE applies the LTE predicate on the "success_count" field.
func SuccessCountNEQ ¶
SuccessCountNEQ applies the NEQ predicate on the "success_count" field.
func SuccessCountNotIn ¶
SuccessCountNotIn applies the NotIn predicate on the "success_count" field.
func SuccessThreshold ¶
SuccessThreshold applies equality check predicate on the "success_threshold" field. It's identical to SuccessThresholdEQ.
func SuccessThresholdEQ ¶
SuccessThresholdEQ applies the EQ predicate on the "success_threshold" field.
func SuccessThresholdGT ¶
SuccessThresholdGT applies the GT predicate on the "success_threshold" field.
func SuccessThresholdGTE ¶
SuccessThresholdGTE applies the GTE predicate on the "success_threshold" field.
func SuccessThresholdIn ¶
SuccessThresholdIn applies the In predicate on the "success_threshold" field.
func SuccessThresholdLT ¶
SuccessThresholdLT applies the LT predicate on the "success_threshold" field.
func SuccessThresholdLTE ¶
SuccessThresholdLTE applies the LTE predicate on the "success_threshold" field.
func SuccessThresholdNEQ ¶
SuccessThresholdNEQ applies the NEQ predicate on the "success_threshold" field.
func SuccessThresholdNotIn ¶
SuccessThresholdNotIn applies the NotIn predicate on the "success_threshold" field.
func TagsNotNil ¶
TagsNotNil applies the NotNil predicate on the "tags" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.