Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Sink) predicate.Sink
- func CreatedAt(v time.Time) predicate.Sink
- func CreatedAtEQ(v time.Time) predicate.Sink
- func CreatedAtGT(v time.Time) predicate.Sink
- func CreatedAtGTE(v time.Time) predicate.Sink
- func CreatedAtIn(vs ...time.Time) predicate.Sink
- func CreatedAtLT(v time.Time) predicate.Sink
- func CreatedAtLTE(v time.Time) predicate.Sink
- func CreatedAtNEQ(v time.Time) predicate.Sink
- func CreatedAtNotIn(vs ...time.Time) predicate.Sink
- func ID(id string) predicate.Sink
- func IDEQ(id string) predicate.Sink
- func IDGT(id string) predicate.Sink
- func IDGTE(id string) predicate.Sink
- func IDIn(ids ...string) predicate.Sink
- func IDLT(id string) predicate.Sink
- func IDLTE(id string) predicate.Sink
- func IDNEQ(id string) predicate.Sink
- func IDNotIn(ids ...string) predicate.Sink
- func Not(p predicate.Sink) predicate.Sink
- func Or(predicates ...predicate.Sink) predicate.Sink
- func SinkType(v string) predicate.Sink
- func SinkTypeContains(v string) predicate.Sink
- func SinkTypeContainsFold(v string) predicate.Sink
- func SinkTypeEQ(v string) predicate.Sink
- func SinkTypeEqualFold(v string) predicate.Sink
- func SinkTypeGT(v string) predicate.Sink
- func SinkTypeGTE(v string) predicate.Sink
- func SinkTypeHasPrefix(v string) predicate.Sink
- func SinkTypeHasSuffix(v string) predicate.Sink
- func SinkTypeIn(vs ...string) predicate.Sink
- func SinkTypeLT(v string) predicate.Sink
- func SinkTypeLTE(v string) predicate.Sink
- func SinkTypeNEQ(v string) predicate.Sink
- func SinkTypeNotIn(vs ...string) predicate.Sink
- func UpdatedAt(v time.Time) predicate.Sink
- func UpdatedAtEQ(v time.Time) predicate.Sink
- func UpdatedAtGT(v time.Time) predicate.Sink
- func UpdatedAtGTE(v time.Time) predicate.Sink
- func UpdatedAtIn(vs ...time.Time) predicate.Sink
- func UpdatedAtLT(v time.Time) predicate.Sink
- func UpdatedAtLTE(v time.Time) predicate.Sink
- func UpdatedAtNEQ(v time.Time) predicate.Sink
- func UpdatedAtNotIn(vs ...time.Time) predicate.Sink
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the sink type in the database. Label = "sink" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldSinkType holds the string denoting the sink_type field in the database. FieldSinkType = "sink_type" // FieldConfig holds the string denoting the config field in the database. FieldConfig = "config" // Table holds the table name of the sink in the database. Table = "sinks" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // SinkTypeValidator is a validator for the "sink_type" field. It is called by the builders before save. SinkTypeValidator func(string) error // IDValidator is a validator for the "id" field. It is called by the builders before save. IDValidator func(string) error )
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldSinkType, FieldConfig, }
Columns holds all SQL columns for sink fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func SinkType ¶
SinkType applies equality check predicate on the "sink_type" field. It's identical to SinkTypeEQ.
func SinkTypeContains ¶
SinkTypeContains applies the Contains predicate on the "sink_type" field.
func SinkTypeContainsFold ¶
SinkTypeContainsFold applies the ContainsFold predicate on the "sink_type" field.
func SinkTypeEQ ¶
SinkTypeEQ applies the EQ predicate on the "sink_type" field.
func SinkTypeEqualFold ¶
SinkTypeEqualFold applies the EqualFold predicate on the "sink_type" field.
func SinkTypeGT ¶
SinkTypeGT applies the GT predicate on the "sink_type" field.
func SinkTypeGTE ¶
SinkTypeGTE applies the GTE predicate on the "sink_type" field.
func SinkTypeHasPrefix ¶
SinkTypeHasPrefix applies the HasPrefix predicate on the "sink_type" field.
func SinkTypeHasSuffix ¶
SinkTypeHasSuffix applies the HasSuffix predicate on the "sink_type" field.
func SinkTypeIn ¶
SinkTypeIn applies the In predicate on the "sink_type" field.
func SinkTypeLT ¶
SinkTypeLT applies the LT predicate on the "sink_type" field.
func SinkTypeLTE ¶
SinkTypeLTE applies the LTE predicate on the "sink_type" field.
func SinkTypeNEQ ¶
SinkTypeNEQ applies the NEQ predicate on the "sink_type" field.
func SinkTypeNotIn ¶
SinkTypeNotIn applies the NotIn predicate on the "sink_type" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.